==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/script/personscripts.js <==


$(function() {
    let
        prechodneBydlisteClick = function() {
        },

        prechodneKontaktniClick = function() {
            if ($(this).prop("checked")) {
                $("#osoba_trvalebydliste_kontaktniadresa").prop("checked", false);
            }
        },

        trvaleKontaktniClick = function() {
            if ($(this).prop("checked")) {
                $("#osoba_prechodnebydliste_kontaktniadresa").prop("checked", false);
            }
        },

        kodVzdelaniChange = function() {
            let value = $(this).val();

            switch (value) {
                case "1" : // bez
                case "2" : // neuplne zakladni
                    $("#datumUkonceniStudia").val($("#osoba_datumnarozeni").val());
                case "3" : // zakladni
                    $("#oborVzdelani").ronselect("value", "0000"); // neurcen
                    $("#vzdelaniUkonceno").val("0"); // nezkouseno
                    break;

            }
        };

    $("#formnovyzamestnanec")
        .on("click", "#osoba_prechodnebydliste_existuje", prechodneBydlisteClick)
        .on("click", "#osoba_prechodnebydliste_kontaktniadresa", prechodneKontaktniClick)
        .on("click", "#osoba_trvalebydliste_kontaktniadresa", trvaleKontaktniClick)
        .on("change", "#kodVzdelani", kodVzdelaniChange)
    ;
});


var personalistika = { };
personalistika.UrovenDovednosti = function() {
    this.kod = 0;
    this.popis = '';
};

personalistika.zobrazUrovneDovednosti = function(kodDovednosti) {
    var vynulujSelect = function(select) {
        $(select).find('option').remove();
    };
    var zobrazData = function(data) {
        var select = $('#urovneDovednosti').find('select[name="urovenDovednosti"]');

        if (!data  ||  !data.urovne)
        {
            vynulujSelect(select);
            return;
        }

        vynulujSelect(select);

        $.each(data.urovne, function(key, value) {
            $(select)
                .append($('<option>', {value : value.kod})
                    .text(value.popis));
        });

    };



    var url = "?menuid=dovednosti&action=loaddata&dovednost=" + kodDovednosti;

    $.ajax(url)
        .done( function(data) {
            if (debugMode) console.log("Nacteny urovne dovednosti: " + kodDovednosti + ". ", data);

            if (data.result == "error") {
                vynulujSelect($('#urovneDovednosti').find('select[name="urovenDovednosti"]'));
                ron.showError(data);
            } else {
                zobrazData(data);
            }

        }).fail( function(jqXHR) {
        vynulujSelect($('#urovneDovednosti').find('select[name="urovenDovednosti"]'));
        ron.showAjaxError(jqXHR, "Pri nacitani urovni dovednosti doslo k chybe!");
    });
};


personalistika.dovednosti = {

    zpracujDialogTPM : function () {
        var editovatTPM = function() {

            $("#dovednosti_tpm_buttonsrow").hide();

            this.form.submit();
            return true;
        };

        var stornoTPM = function() {
            $("#dovednosti_tpm").dialog("close");
        };


        $("#dovednosti_tpm")
            .off("click")
            .on("click", "#dovednosti_tpm_vlozit_Btn", editovatTPM)
            .on("click", "#dovednosti_tpm_storno_Btn", stornoTPM)
            .dialog( {
                position: { my: "center", at: "center", of: 'form:has(select[name=urovenDovednosti])', within: 'form:has(select[name=urovenDovednosti])' },
                modal : true,
                resizable: false,
                width: "auto",
                height: "auto"
            });
    },

    zobrazVlozeniTPM : function () {
        $('#dovednosti_tpm_platnost_do').hide();
        $('#dovednosti_tpm_poznamka').show();
        $('#dovednosti_tpm_kod').show();
        $('#dovednosti_tpm_platnost_od').show();

        personalistika.dovednosti.zpracujDialogTPM();
    },

    zobrazUkonceniTPM : function () {
        $('#dovednosti_tpm_platnost_do').show();
        $('#dovednosti_tpm_poznamka').hide();
        $('#dovednosti_tpm_kod').hide();
        $('#dovednosti_tpm_platnost_od').hide();

        var $this = $(this);

        $('#tpm_kod').prop('value',$this.data('tpm-kod'));
        $('#tpm_platnost_od').prop('value',$this.data('tpm-platnost-od'));

        personalistika.dovednosti.zpracujDialogTPM();
    }
};


function showDokumentDovednostiDialog(idPP) {

    var dokumentDovednostiResult = function(result) {
        processDokumentResult(result, '?menuid=maticedovednosti&action=novadovednost&idosoby=' + idPP);
    };

    ronPortal.showDokumentDialog(dokumentDovednostiResult);
    return false;
}

function showDokumentLekarskeProhlidkyDialog(idOsoby, kodZP, datumVzniku) {

    var dokumentLekarskeProhlidkyResult = function(result) {
        processDokumentResult(result, '?menuid=lekarskeprohlidky&action=detail&osoba=' + idOsoby + '&kod=' + kodZP + '&vznik=' + datumVzniku);
    };

    ronPortal.showDokumentDialog(dokumentLekarskeProhlidkyResult);
}



$( function() {
    $('#dovednosti_nove_tpm').on('click', personalistika.dovednosti.zobrazVlozeniTPM);
    $('#tpm').on('click', 'a.ukonceniTPM', personalistika.dovednosti.zobrazUkonceniTPM);
});

$(function() {

    var
        showRow = function(rowSelector, dataSelector, value) {
            if (value == '') {
                $(rowSelector).addClass('d-none');
            } else {
                $(dataSelector).text(value);
                $(rowSelector).removeClass('d-none');
            }
        },

        zobrazData = function(detailData, doporucenaVelikost) {
            $("#detail_pomucky_nazev").text(detailData.popis + " (" + detailData.kod + ")");
            $("#detail_pomucky_typ").text(detailData.typ);

            showRow("#detail_pomucky_row_inventarni_cislo", "#detail_pomucky_inventarni_cislo", detailData.inventarniCislo);
            showRow("#detail_pomucky_row_vyrobni_cislo", "#detail_pomucky_vyrobni_cislo", detailData.vyrobniCislo);
            showRow("#detail_pomucky_row_znacka", "#detail_pomucky_znacka", detailData.znacka);
            showRow("#detail_pomucky_row_konec_zaruky", "#detail_pomucky_konec_zaruky", detailData.konecZaruky);


            for (var i = 1;  i <= 5;  i++) {
                if (detailData["nadpisUzivatelske" + i]) {
                    $("#detail_pomucky_uzivatelska" + i + "_nadpis")
                        .text(detailData["nadpisUzivatelske" + i]);

                    $("#detail_pomucky_uzivatelska" + i)
                        .text(detailData["uzivatelske" + i]);

                    $("#detail_pomucky_row_uzivatelska" + i).removeClass('d-none');
                } else {
                    $("#detail_pomucky_row_uzivatelska" + i).addClass('d-none');
                }
            }
            $("#doporucenaVelikost").text(doporucenaVelikost);

            var $velikostPP = $("#VelikostPP");
            $velikostPP.empty();
            $velikostPP.append( $("<option/>").attr('value', '').text('') );

            console.log(detailData.velikosti.length, detailData.velikosti);
            if (detailData.velikosti && detailData.velikosti.length) {
                for (i = 0;  i < detailData.velikosti.length;  i++) {
                    $velikostPP.append(
                        $("<option/>")
                            .attr('value', detailData.velikosti[i])
                            .text(detailData.velikosti[i])
                    );
                }
            }
        },

        loadData = function(kod) {
            var idpp = $('#osoba').val();

            $.ajax("?menuid=pracovnipomucky&action=detaildata&kod=" + encodeURIComponent(kod) + (idpp ? '&idpp=' + idpp : ''))
                .done(function(data) {
                    $("#detail_pracovni_pomucky")
                        .removeClass("loading");

                    zobrazData(data.detail, data.doporucenaVelikost);
                })
                .fail(function(jqXHR) {
                    ron.showAjaxError(jqXHR, "Pri nacitani delky smeny doslo k chybe!");
                    $("#detail_pracovni_pomucky")
                        .removeClass("loading")
                });
        },

        onDetailClick = function() {
            $("#detail_pracovni_pomucky")
                .addClass("loading")
                .dialog({
                    modal: true,
                    minHeight: 0,
                    minWidth: 600
                });

            loadData($(this).data('kod'));

            return false;
        },

        onVyberPomuckyChange = function() {
            var newVal = $(this).val();

            if (newVal) {
                $("#detail_pracovni_pomucky")
                    .addClass("loading");

                loadData(newVal);
            }
        },

        onVyberOsobyChange = function() {
            if (!$(this).val()) {
                return;
            }

            var kodPomucky = $("#kod_pracovni_pomucky").val();
            if (kodPomucky) {
                loadData(kodPomucky);
            }
        };


    $("body")
        .on("click", ".pracovni-pomucky-detail-link", onDetailClick)
        .on("change", "#kod_pracovni_pomucky", onVyberPomuckyChange)
        .on("change", "#osoba", onVyberOsobyChange);
});

(function() {
    let
        urlVyhledat = null,
        urlProvest = null,

        vyhledatKurzy = function () {
            if (urlVyhledat) {
                window.location.href = urlVyhledat;
            }
        },

        prihlasitKurz = function () {
            if (urlProvest) {
                window.location.href = urlProvest;
            }
        };
    let vyhledaniKurzuStejneUmisteni = function () {
        let $this = $(this);
        urlVyhledat = $this.data('skoleni-vyhledat');
        urlProvest = $this.data('skoleni-provest');
        $("#dialogSkoleniVyhledatUmisteni")
            .dialog({
                modal: true,
                resizable: false,
                width: "auto",
                height: "auto",
                closeOnEscape: true
            });
    };


    let nactiPodrobnostiSkoleni = function() {
        $("#pozadavek_na_skoleni_kapacita").text("");
        $("#pozadavek_na_skoleni_pocet_prihlasenych").text("");

        let $this = $(this);

        if ($this.val()) {
            $.ajax("?menuid=skolenijs&action=kapacitaskoleni&cisloskoleni=" + $this.val())
                .done(function (data) {
                    $("#pozadavek_na_skoleni_kapacita").text(data.kapacita ? data.kapacita : "");
                    $("#pozadavek_na_skoleni_pocet_prihlasenych").text(data.pocetPrihlasenych ? data.pocetPrihlasenych : "0");

                    let $datum = $("#pozadavek_na_skoleni_pozadovane_datum");
                    $datum.val(data.datumPocatkuSkoleni);
                })
                .fail(function (jqXHR) {
                    ron.showAjaxError(jqXHR, "Pri nacitani kapacity skoleni doslo k chybe!");
                });
        }
    };


    $(function() {
        $('.prihlaseniSkoleniBrowser')
            .on('click', '.skoleniVyhledatUmisteni', vyhledaniKurzuStejneUmisteni);

        $(document)
            .on("click", "#btnVyhledatUmisteni", vyhledatKurzy)
            .on("click", "#btnPrihlasitKurz", prihlasitKurz)
            .on("change", "#pozadavek_na_skoleni_kurz", nactiPodrobnostiSkoleni);
    });
})();


(function() {

    let
        url = null,

        dialogSmazatTerminy = function () {
            $("#dialogSkoleniTerminy")
                .dialog({
                    modal: true,
                    resizable: false,
                    width: "auto",
                    height: "auto",
                    closeOnEscape: true
                });

        },

        dialogSmazatSkoleni = function () {
            $("#dialogSkoleniNavrh")
                .dialog({
                    modal: true,
                    resizable: false,
                    width: "auto",
                    height: "auto",
                    closeOnEscape: true
                });

        },

        smazatSkoleniClick = function () {
            window.location.href = url + '&navrh=smazat';
        },

        ponechatNavrhClick = function () {
            $(this).off('click');
            $("#btnSmazatNavrh").off('click');
            window.location.href = url + '&navrh=zrusit';
        };
    let odhlaseniClick = function($event) {
        let
            $element = $(this); // puvodni element, na ktery uzivatel klikl

        url = $element.attr("href");

        if ($element.data('prihlaseny-terminy') == 1) {
            $event.preventDefault();
            dialogSmazatTerminy();
            return false;
        } else if ($element.data('ponechat-navrh') == 0) {
            $event.preventDefault();
            dialogSmazatSkoleni();
            return false;
        }

        return true;

    };


    $(function() {
        $('.prihlaseniSkoleniBrowser')
            .on('click', 'a[data-prihlaseny-terminy]', odhlaseniClick);

        $("#btnTerminySmazat")
            .on("click", function () {
                $("#dialogSkoleniTerminy").dialog('close');
                dialogSmazatSkoleni();
            });

        $("#btnPonechatNavrh")
            .on("click", ponechatNavrhClick);

        $("#btnSmazatNavrh")
            .on("click", smazatSkoleniClick);
    })
})();

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/script/personscripts.js <==


$(function() {
    let
        prechodneBydlisteClick = function() {
        },

        prechodneKontaktniClick = function() {
            if ($(this).prop("checked")) {
                $("#osoba_trvalebydliste_kontaktniadresa").prop("checked", false);
            }
        },

        trvaleKontaktniClick = function() {
            if ($(this).prop("checked")) {
                $("#osoba_prechodnebydliste_kontaktniadresa").prop("checked", false);
            }
        },

        kodVzdelaniChange = function() {
            let value = $(this).val();

            switch (value) {
                case "1" : // bez
                case "2" : // neuplne zakladni
                    $("#datumUkonceniStudia").val($("#osoba_datumnarozeni").val());
                case "3" : // zakladni
                    $("#oborVzdelani").ronselect("value", "0000"); // neurcen
                    $("#vzdelaniUkonceno").val("0"); // nezkouseno
                    break;

            }
        };

    $("#formnovyzamestnanec")
        .on("click", "#osoba_prechodnebydliste_existuje", prechodneBydlisteClick)
        .on("click", "#osoba_prechodnebydliste_kontaktniadresa", prechodneKontaktniClick)
        .on("click", "#osoba_trvalebydliste_kontaktniadresa", trvaleKontaktniClick)
        .on("change", "#kodVzdelani", kodVzdelaniChange)
    ;
});


var personalistika = { };
personalistika.UrovenDovednosti = function() {
    this.kod = 0;
    this.popis = '';
};

personalistika.nactiDataFormulare = function() {
    let vynulujSelect = function(select) {
        $(select).find('option').remove();
    };
    let zobrazData = function(data) {
        let selectUrovne = $('#urovneDovednosti').find('select[name="urovenDovednosti"]'),
            selectDovednosti = $('#dovednost_vyber');

        if (!data  || data.urovne === undefined || data.urovne.length === 0) {
            vynulujSelect(selectUrovne);
            return;
        }

        vynulujSelect(selectUrovne);

        $.each(data.urovne, function(key, value) {
            $(selectUrovne)
                .append($('<option>', {value : value.kod})
                    .text(value.popis));
        });
    };

    let $this = $(this),
        url = '',
        dovednosti = false;
    if ($this.prop('id') === 'osoba_vyber') {
        url = "?menuid=dovednosti&action=loaddata&osoba=" + $this.val();
        dovednosti = true;

        window.location = '?menuid=maticedovednosti&action=novadovednost&osoba=' + $this.val();
        return;
    } else if ($this.prop('id') === 'dovednost_vyber') {
        url = "?menuid=dovednosti&action=loaddata&dovednost=" + $this.val();
    }

    if (url) {
        $.ajax(url)
            .done(function (data) {
                if (debugMode) console.log("Nacteny data dovednosti: " + kodDovednosti + ". ", data);

                if (data.result == "error") {
                    if (dovednosti) {
                        vynulujSelect($('#dovednost_vyber'));
                    }
                    vynulujSelect($('#urovneDovednosti').find('select[name="urovenDovednosti"]'));
                    ron.showError(data);
                } else {
                    zobrazData(data);
                }

            }).fail(function (jqXHR) {
                if (dovednosti) {
                    vynulujSelect($('#dovednost_vyber'));
                }
                vynulujSelect($('#urovneDovednosti').find('select[name="urovenDovednosti"]'));
                ron.showAjaxError(jqXHR, "Pri nacitani urovni dovednosti doslo k chybe!");
        });
    }
};


personalistika.dovednosti = {

    zpracujDialogTPM : function () {
        var editovatTPM = function() {

            $("#dovednosti_tpm_buttonsrow").hide();

            this.form.submit();
            return true;
        };

        var stornoTPM = function() {
            $("#dovednosti_tpm").dialog("close");
        };


        $("#dovednosti_tpm")
            .off("click")
            .on("click", "#dovednosti_tpm_vlozit_Btn", editovatTPM)
            .on("click", "#dovednosti_tpm_storno_Btn", stornoTPM)
            .dialog( {
                position: { my: "center", at: "center", of: 'form:has(select[name=urovenDovednosti])', within: 'form:has(select[name=urovenDovednosti])' },
                modal : true,
                resizable: false,
                width: "auto",
                height: "auto"
            });
    },

    zobrazVlozeniTPM : function () {
        $('#dovednosti_tpm_platnost_do').hide();
        $('#dovednosti_tpm_poznamka').show();
        $('#dovednosti_tpm_kod').show();
        $('#dovednosti_tpm_platnost_od').show();

        personalistika.dovednosti.zpracujDialogTPM();
    },

    zobrazUkonceniTPM : function () {
        $('#dovednosti_tpm_platnost_do').show();
        $('#dovednosti_tpm_poznamka').hide();
        $('#dovednosti_tpm_kod').hide();
        $('#dovednosti_tpm_platnost_od').hide();

        var $this = $(this);

        $('#tpm_kod').prop('value',$this.data('tpm-kod'));
        $('#tpm_platnost_od').prop('value',$this.data('tpm-platnost-od'));

        personalistika.dovednosti.zpracujDialogTPM();
    }
};

function showDokumentLekarskeProhlidkyDialog(idOsoby, kodZP, datumVzniku) {

    var dokumentLekarskeProhlidkyResult = function(result) {
        processDokumentResult(result, '?menuid=lekarskeprohlidky&action=detail&osoba=' + idOsoby + '&kod=' + kodZP + '&vznik=' + datumVzniku);
    };

    ronPortal.showDokumentDialog(dokumentLekarskeProhlidkyResult);
}



$( function() {
    $('#dovednosti_nove_tpm').on('click', personalistika.dovednosti.zobrazVlozeniTPM);
    $('#tpm').on('click', 'a.ukonceniTPM', personalistika.dovednosti.zobrazUkonceniTPM);
    $('#dovednost_vyber, #osoba_vyber').on('change', personalistika.nactiDataFormulare);
});

$(function() {

    var
        showRow = function(rowSelector, dataSelector, value) {
            if (value == '') {
                $(rowSelector).addClass('d-none');
            } else {
                $(dataSelector).text(value);
                $(rowSelector).removeClass('d-none');
            }
        },

        zobrazData = function(detailData, doporucenaVelikost) {
            $("#detail_pomucky_nazev").text(detailData.popis + " (" + detailData.kod + ")");
            $("#detail_pomucky_typ").text(detailData.typ);

            showRow("#detail_pomucky_row_inventarni_cislo", "#detail_pomucky_inventarni_cislo", detailData.inventarniCislo);
            showRow("#detail_pomucky_row_vyrobni_cislo", "#detail_pomucky_vyrobni_cislo", detailData.vyrobniCislo);
            showRow("#detail_pomucky_row_znacka", "#detail_pomucky_znacka", detailData.znacka);
            showRow("#detail_pomucky_row_konec_zaruky", "#detail_pomucky_konec_zaruky", detailData.konecZaruky);


            for (var i = 1;  i <= 5;  i++) {
                if (detailData["nadpisUzivatelske" + i]) {
                    $("#detail_pomucky_uzivatelska" + i + "_nadpis")
                        .text(detailData["nadpisUzivatelske" + i]);

                    $("#detail_pomucky_uzivatelska" + i)
                        .text(detailData["uzivatelske" + i]);

                    $("#detail_pomucky_row_uzivatelska" + i).removeClass('d-none');
                } else {
                    $("#detail_pomucky_row_uzivatelska" + i).addClass('d-none');
                }
            }
            $("#doporucenaVelikost").text(doporucenaVelikost);

            var $velikostPP = $("#VelikostPP");
            $velikostPP.empty();
            $velikostPP.append( $("<option/>").attr('value', '').text('') );

            console.log(detailData.velikosti.length, detailData.velikosti);
            if (detailData.velikosti && detailData.velikosti.length) {
                for (i = 0;  i < detailData.velikosti.length;  i++) {
                    $velikostPP.append(
                        $("<option/>")
                            .attr('value', detailData.velikosti[i])
                            .text(detailData.velikosti[i])
                    );
                }
            }
        },

        loadData = function(kod) {
            var idpp = $('#osoba').val();

            $.ajax("?menuid=pracovnipomucky&action=detaildata&kod=" + encodeURIComponent(kod) + (idpp ? '&idpp=' + idpp : ''))
                .done(function(data) {
                    $("#detail_pracovni_pomucky")
                        .removeClass("loading");

                    zobrazData(data.detail, data.doporucenaVelikost);
                })
                .fail(function(jqXHR) {
                    ron.showAjaxError(jqXHR, "Pri nacitani delky smeny doslo k chybe!");
                    $("#detail_pracovni_pomucky")
                        .removeClass("loading")
                });
        },

        onDetailClick = function() {
            $("#detail_pracovni_pomucky")
                .addClass("loading")
                .dialog({
                    modal: true,
                    minHeight: 0,
                    minWidth: 600
                });

            loadData($(this).data('kod'));

            return false;
        },

        onVyberPomuckyChange = function() {
            var newVal = $(this).val();

            if (newVal) {
                $("#detail_pracovni_pomucky")
                    .addClass("loading");

                loadData(newVal);
            }
        },

        onVyberOsobyChange = function() {
            if (!$(this).val()) {
                return;
            }

            var kodPomucky = $("#kod_pracovni_pomucky").val();
            if (kodPomucky) {
                loadData(kodPomucky);
            }
        };


    $("body")
        .on("click", ".pracovni-pomucky-detail-link", onDetailClick)
        .on("change", "#kod_pracovni_pomucky", onVyberPomuckyChange)
        .on("change", "#osoba", onVyberOsobyChange);
});

(function() {
    let
        urlVyhledat = null,
        urlProvest = null,

        vyhledatKurzy = function () {
            if (urlVyhledat) {
                window.location.href = urlVyhledat;
            }
        },

        prihlasitKurz = function () {
            if (urlProvest) {
                window.location.href = urlProvest;
            }
        };
    let vyhledaniKurzuStejneUmisteni = function () {
        let $this = $(this);
        urlVyhledat = $this.data('skoleni-vyhledat');
        urlProvest = $this.data('skoleni-provest');
        $("#dialogSkoleniVyhledatUmisteni")
            .dialog({
                modal: true,
                resizable: false,
                width: "auto",
                height: "auto",
                closeOnEscape: true
            });
    };


    let nactiPodrobnostiSkoleni = function() {
        $("#pozadavek_na_skoleni_kapacita").text("");
        $("#pozadavek_na_skoleni_pocet_prihlasenych").text("");

        let $this = $(this);

        if ($this.val()) {
            $.ajax("?menuid=skolenijs&action=kapacitaskoleni&cisloskoleni=" + $this.val())
                .done(function (data) {
                    $("#pozadavek_na_skoleni_kapacita").text(data.kapacita ? data.kapacita : "");
                    $("#pozadavek_na_skoleni_pocet_prihlasenych").text(data.pocetPrihlasenych ? data.pocetPrihlasenych : "0");

                    let $datum = $("#pozadavek_na_skoleni_pozadovane_datum");
                    $datum.val(data.datumPocatkuSkoleni);
                })
                .fail(function (jqXHR) {
                    ron.showAjaxError(jqXHR, "Pri nacitani kapacity skoleni doslo k chybe!");
                });
        }
    };


    $(function() {
        $('.prihlaseniSkoleniBrowser')
            .on('click', '.skoleniVyhledatUmisteni', vyhledaniKurzuStejneUmisteni);

        $(document)
            .on("click", "#btnVyhledatUmisteni", vyhledatKurzy)
            .on("click", "#btnPrihlasitKurz", prihlasitKurz)
            .on("change", "#pozadavek_na_skoleni_kurz", nactiPodrobnostiSkoleni);
    });
})();


(function() {

    let
        url = null,

        dialogSmazatTerminy = function () {
            $("#dialogSkoleniTerminy")
                .dialog({
                    modal: true,
                    resizable: false,
                    width: "auto",
                    height: "auto",
                    closeOnEscape: true
                });

        },

        dialogSmazatSkoleni = function () {
            $("#dialogSkoleniNavrh")
                .dialog({
                    modal: true,
                    resizable: false,
                    width: "auto",
                    height: "auto",
                    closeOnEscape: true
                });

        },

        smazatSkoleniClick = function () {
            window.location.href = url + '&navrh=smazat';
        },

        ponechatNavrhClick = function () {
            $(this).off('click');
            $("#btnSmazatNavrh").off('click');
            window.location.href = url + '&navrh=zrusit';
        };
    let odhlaseniClick = function($event) {
        let
            $element = $(this); // puvodni element, na ktery uzivatel klikl

        url = $element.attr("href");

        if ($element.data('prihlaseny-terminy') == 1) {
            $event.preventDefault();
            dialogSmazatTerminy();
            return false;
        } else if ($element.data('ponechat-navrh') == 0) {
            $event.preventDefault();
            dialogSmazatSkoleni();
            return false;
        }

        return true;

    };


    $(function() {
        $('.prihlaseniSkoleniBrowser')
            .on('click', 'a[data-prihlaseny-terminy]', odhlaseniClick);

        $("#btnTerminySmazat")
            .on("click", function () {
                $("#dialogSkoleniTerminy").dialog('close');
                dialogSmazatSkoleni();
            });

        $("#btnPonechatNavrh")
            .on("click", ponechatNavrhClick);

        $("#btnSmazatNavrh")
            .on("click", smazatSkoleniClick);
    })
})();
